/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: 8480_SUPSTP_LOAD_ULTCOTFORN                                          */
/*                                                                            */
/* Descrio:                                                                 */
/*    Carrega a ltima cotao para do fornecedor                             */
/*                                                                            */
/* Criao:                                                                   */
/*    03/07/2000 - Adriano de Araujo                                          */
/*                                                                            */
/* Manutenes:                                                               */
/*   /  /   -                                                                 */
/*                                                                            */
/******************************************************************************/

IF EXISTS (SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'LOAD_ULTCOTFORN'  and
            type = 'P'                  and
            u.uid = o.uid               and
            u.name = USER)

   DROP PROCEDURE LOAD_ULTCOTFORN;
GO

CREATE PROCEDURE LOAD_ULTCOTFORN
                  @P_CDFILIAL VARCHAR(4),
                  @P_NRCOLEPRECO VARCHAR(10),
                  @P_CDFORNECED VARCHAR(21)
AS
DECLARE @V_ULTCOT VARCHAR(10);
DECLARE @V_DTCOL  DATETIME;
 
BEGIN
  SELECT
    @V_DTCOL = DTCOLEPREC
  FROM
   COLETAPR
  WHERE
   CDFILIAL    = @P_CDFILIAL AND
   NRCOLEPRECO = @P_NRCOLEPRECO;

  SELECT
    @V_ULTCOT = CONVERT(VARCHAR, ISNULL(MAX(ITEMCOLE.NRCOLEPRECO), 0))
  FROM
    ITEMCOLE,
    FORNECEDOR
  WHERE
    ITEMCOLE.CDFILIAL     = @P_CDFILIAL   AND
    ITEMCOLE.CDFORNECED   = @P_CDFORNECED AND
    ITEMCOLE.NRCOLEPRECO  <> @P_NRCOLEPRECO AND
    ITEMCOLE.CDFORNECED   = FORNECEDOR.CDFORNECED AND
    FORNECEDOR.IDSITUCADA = 'A' AND
    NOT EXISTS
     (SELECT
        FORNECEDOR.CDFORNECED
      FROM
        QUALIFICACAO,
        PARASUPRI
      WHERE
        FORNECEDOR.CDQUALIF = QUALIFICACAO.CDQUALIF AND
        (PARASUPRI.CDFILIAL = @P_CDFILIAL) AND
        (FORNECEDOR.IDFORNAUTO = 'N') AND
        ((QUALIFICACAO.IDPERCOTCMP = '2') OR
        ( (PARASUPRI.IDULTIDTVALQ = 'D' AND
         @V_DTCOL > FORNECEDOR.DTVALQUALIF) OR
        (PARASUPRI.IDULTIDTVALQ = 'M' AND
         @V_DTCOL > DATEADD(MM, 1, FORNECEDOR.DTVALQUALIF) - DAY(DATEADD(MM, 1, FORNECEDOR.DTVALQUALIF)) ) )) );

  UPDATE ITEMCOLE
  SET
     ITEMCOLE.VRPRECUNIITM = ULT_ITM.VRPRECUNIITM,
     ITEMCOLE.CDTIPCOB     = ULT_ITM.CDTIPCOB,
     ITEMCOLE.CDSEGMARCCOL = ULT_ITM.CDSEGMARCCOL,
     ITEMCOLE.VRPERDESITM  = ULT_ITM.VRPERDESITM,
     ITEMCOLE.IDTIPFREITM  = ULT_ITM.IDTIPFREITM,
     ITEMCOLE.NRPZOENTCOL  = ULT_ITM.NRPZOENTCOL,
     ITEMCOLE.CDFORMPGTO   = ULT_ITM.CDFORMPGTO,
     ITEMCOLE.IDTPFOPGTCOL = ULT_ITM.IDTPFOPGTCOL,
     ITEMCOLE.NRPARCPGTCOL = ULT_ITM.NRPARCPGTCOL,
     ITEMCOLE.NRDIAPGFXCOL = ULT_ITM.NRDIAPGFXCOL,
     ITEMCOLE.IDUTDIAPGCOL = ULT_ITM.IDUTDIAPGCOL,
     ITEMCOLE.DSPZOPGTCONC = ULT_ITM.DSPZOPGTCONC
  FROM
   (SELECT
      ITEMCOLE.CDFILIAL,
      ITEMCOLE.NRCOLEPRECO,
      ITEMCOLE.CDFORNECED,
      ITEMCOLE.CDREGIAO,
      ITEMCOLE.CDPRODUTO,
      ITEMCOLE.CDMARCA,
      ITEMCOLE.VRPRECUNIITM,
      ITEMCOLE.CDTIPCOB,
      ITEMCOLE.CDSEGMARCCOL,
      ITEMCOLE.VRPERDESITM,
      ITEMCOLE.IDTIPFREITM,
      ITEMCOLE.NRPZOENTCOL,
      ITEMCOLE.CDFORMPGTO,
      ITEMCOLE.IDTPFOPGTCOL,
      ITEMCOLE.NRPARCPGTCOL,
      ITEMCOLE.NRDIAPGFXCOL,
      ITEMCOLE.IDUTDIAPGCOL,
      ITEMCOLE.DSPZOPGTCONC
     FROM
        ITEMCOLE
     WHERE
        ITEMCOLE.CDFILIAL     = @P_CDFILIAL AND
        ITEMCOLE.NRCOLEPRECO  = @V_ULTCOT  AND
        ITEMCOLE.CDFORNECED   = @P_CDFORNECED) ULT_ITM
  WHERE
     ITEMCOLE.CDFILIAL     = @P_CDFILIAL     AND
     ITEMCOLE.NRCOLEPRECO  = @P_NRCOLEPRECO  AND

     ITEMCOLE.CDFILIAL     = ULT_ITM.CDFILIAL   AND
     ITEMCOLE.CDFORNECED   = ULT_ITM.CDFORNECED AND
     ITEMCOLE.CDPRODUTO    = ULT_ITM.CDPRODUTO  AND
     ITEMCOLE.CDMARCA      = ULT_ITM.CDMARCA    AND
     ITEMCOLE.CDREGIAO     = ULT_ITM.CDREGIAO

  IF @@ROWCOUNT > 0
  BEGIN
    INSERT INTO PZOPGTITMCOL
      (CDFILIAL, NRCOLEPRECO, CDFORNECED, CDPRODUTO,
      CDMARCA, CDREGIAO, NRDIASPGTCOL, VRPERCPGTCOL)
    SELECT
       PZOPGTITMCOL.CDFILIAL,
       @P_NRCOLEPRECO,
       PZOPGTITMCOL.CDFORNECED,
       PZOPGTITMCOL.CDPRODUTO,
       PZOPGTITMCOL.CDMARCA,
       PZOPGTITMCOL.CDREGIAO,
       PZOPGTITMCOL.NRDIASPGTCOL,
       PZOPGTITMCOL.VRPERCPGTCOL
    FROM
       PZOPGTITMCOL,
       (SELECT
          ITEMCOLE.CDFORNECED,
          ITEMCOLE.CDPRODUTO,
          ITEMCOLE.CDMARCA,
          ITEMCOLE.CDREGIAO
        FROM
          ITEMCOLE
        WHERE
          ITEMCOLE.CDFILIAL    = @P_CDFILIAL AND
          ITEMCOLE.NRCOLEPRECO = @P_NRCOLEPRECO) ITEMCOLE
    WHERE
       PZOPGTITMCOL.CDFILIAL    = @P_CDFILIAL   AND
       PZOPGTITMCOL.NRCOLEPRECO = @V_ULTCOT     AND
       PZOPGTITMCOL.CDFORNECED  = @P_CDFORNECED AND
       ITEMCOLE.CDFORNECED  = PZOPGTITMCOL.CDFORNECED AND
       ITEMCOLE.CDPRODUTO   = PZOPGTITMCOL.CDPRODUTO  AND
       ITEMCOLE.CDMARCA     = PZOPGTITMCOL.CDMARCA    AND
       ITEMCOLE.CDREGIAO    = PZOPGTITMCOL.CDREGIAO;

    INSERT INTO IMPCOLET
      (CDFILIAL, NRCOLEPRECO, CDFORNECED, CDPRODUTO,
       CDMARCA, CDREGIAO, CDIMPOSTO, VRALIQIMPCOL,
       VRPERRBCALCO, VRIMPCOLETA, VRBASECALCOL,
       VRPARCDEDCOL, CDFISCITMCOL, VRADIMPCOL)
    SELECT
      IMPCOLET.CDFILIAL,
      @P_NRCOLEPRECO,
      IMPCOLET.CDFORNECED,
      IMPCOLET.CDPRODUTO,
      IMPCOLET.CDMARCA,
      IMPCOLET.CDREGIAO,
      IMPCOLET.CDIMPOSTO,
      IMPCOLET.VRALIQIMPCOL,
      IMPCOLET.VRPERRBCALCO,
      IMPCOLET.VRIMPCOLETA,
      IMPCOLET.VRBASECALCOL,
      IMPCOLET.VRPARCDEDCOL,
      IMPCOLET.CDFISCITMCOL,
      IMPCOLET.VRADIMPCOL
    FROM
      IMPCOLET,
      (SELECT
         ITEMCOLE.CDFORNECED,
         ITEMCOLE.CDPRODUTO,
         ITEMCOLE.CDMARCA,
         ITEMCOLE.CDREGIAO
       FROM
         ITEMCOLE
       WHERE
         ITEMCOLE.CDFILIAL    = @P_CDFILIAL AND
         ITEMCOLE.NRCOLEPRECO = @P_NRCOLEPRECO) ITEMCOLE
    WHERE
      IMPCOLET.CDFILIAL    = @P_CDFILIAL AND
      IMPCOLET.NRCOLEPRECO = @V_ULTCOT   AND
      IMPCOLET.CDFORNECED  = @P_CDFORNECED       AND
      ITEMCOLE.CDFORNECED  = IMPCOLET.CDFORNECED AND
      ITEMCOLE.CDPRODUTO   = IMPCOLET.CDPRODUTO  AND
      ITEMCOLE.CDMARCA     = IMPCOLET.CDMARCA    AND
      ITEMCOLE.CDREGIAO    = IMPCOLET.CDREGIAO;

    /* Forando execuo da trigger para clculo do preo econmico */
    UPDATE ITEMCOLE
    SET IDTPFOPGTCOL = IDTPFOPGTCOL
    WHERE
     CDFILIAL    = @P_CDFILIAL  AND
     NRCOLEPRECO = @P_NRCOLEPRECO;
  END;
END;

GO
